.. strongdoc documentation master file, created by
   sphinx-quickstart on Mon Mar  2 11:39:02 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to strongdoc's documentation!
=====================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :glob:
   :reversed:

   strongdoc
   strongdoc.api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
